==> libreoffice_4.2.3~rc3.orig-src.tar.xz: libwpd-0.9.9/src/lib/WP5SingleByteFunction.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* libwpd
 * Version: MPL 2.0 / LGPLv2.1+
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Major Contributor(s):
 * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
 * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
 * Copyright (C) 2004 Fridrich Strba (fridrich.strba@bluewin.ch)
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU Lesser General Public License Version 2.1 or later
 * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
 * applicable instead of those above.
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP5SINGLEBYTEFUNCTION_H
#define WP5SINGLEBYTEFUNCTION_H

#include "WP5Part.h"

class WP5SingleByteFunction : public WP5Part
{
public:
	static WP5SingleByteFunction *constructSingleByteFunction(WPXInputStream *input, WPXEncryption *encryption, uint8_t groupID);
};

class WP5EOLFunction : public WP5SingleByteFunction
{
public:
	void parse(WP5Listener *listener);
};

class WP5SpaceFunction : public WP5SingleByteFunction
{
public:
	void parse(WP5Listener *listener);
};

class WP5HardSpaceFunction : public WP5SingleByteFunction
{
public:
	void parse(WP5Listener *listener);
};


class WP5HyphenFunction : public WP5SingleByteFunction
{
public:
	void parse(WP5Listener *listener);
};

class WP5SoftHyphenFunction : public WP5SingleByteFunction
{
public:
	void parse(WP5Listener *listener);
};

#endif /* WP5SINGLEBYTEFUNCTION_H */
/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */

==> libreoffice_5.3.1.orig-src.tar.xz: libwpd-0.10.1/src/lib/WP5SingleByteFunction.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* libwpd
 * Version: MPL 2.0 / LGPLv2.1+
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * Major Contributor(s):
 * Copyright (C) 2002 William Lachance (wrlach@gmail.com)
 * Copyright (C) 2002 Marc Maurer (uwog@uwog.net)
 * Copyright (C) 2004 Fridrich Strba (fridrich.strba@bluewin.ch)
 *
 * For minor contributions see the git repository.
 *
 * Alternatively, the contents of this file may be used under the terms
 * of the GNU Lesser General Public License Version 2.1 or later
 * (LGPLv2.1+), in which case the provisions of the LGPLv2.1+ are
 * applicable instead of those above.
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP5SINGLEBYTEFUNCTION_H
#define WP5SINGLEBYTEFUNCTION_H

#include "WP5Part.h"

class WP5SingleByteFunction : public WP5Part
{
public:
	static WP5SingleByteFunction *constructSingleByteFunction(librevenge::RVNGInputStream *input, WPXEncryption *encryption, unsigned char groupID);
};

class WP5EOLFunction : public WP5SingleByteFunction
{
public:
	void parse(WP5Listener *listener);
};

class WP5SpaceFunction : public WP5SingleByteFunction
{
public:
	void parse(WP5Listener *listener);
};

class WP5HardSpaceFunction : public WP5SingleByteFunction
{
public:
	void parse(WP5Listener *listener);
};


class WP5HyphenFunction : public WP5SingleByteFunction
{
public:
	void parse(WP5Listener *listener);
};

class WP5SoftHyphenFunction : public WP5SingleByteFunction
{
public:
	void parse(WP5Listener *listener);
};

#endif /* WP5SINGLEBYTEFUNCTION_H */
/* vim:set shiftwidth=4 softtabstop=4 noexpandtab: */
